Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Lexer ¶
type Lexer struct {
// contains filtered or unexported fields
}
func NewLexerFrom ¶ added in v0.2.1
NewLexerFrom creates a new Lexer with token types and patterns from the given text
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
func NewParserFrom ¶ added in v0.2.1
NewParserFrom creates a new Parser from the given text
Click to show internal directories.
Click to hide internal directories.